@@ -1,12 +1,13 @@
 library(DRomics)
 visualize <- FALSE # put to TRUE for a manual check of plots
+doboot <- FALSE
 
 # importation and check of RNAseq data and normalization
 # with respect to library size and transformation 
 # options to put in shiny : transfo.method (2 methods, rlog or vst)
 datafilename <- system.file("extdata", "RNAseq_sample.txt", package="DRomics")
 (o <- RNAseqdata(datafilename, check = TRUE, transfo.method = "vst"))
-plot(o)
+plot(o, range = 1e6)
 
 if (visualize) # too long computation !
 {
@@ -48,27 +49,18 @@ if(visualize) # too long computation !
 }
 
 
-# item selection using the quadratic method
-# options to put in shiny : select.method (3 methods), FDR (numerical positive value < 1)
-(s_quad <- itemselect(o, select.method = "quadratic", FDR = 0.001))
 if (visualize)
 {
+  # item selection using the quadratic method
+# options to put in shiny : select.method (3 methods), FDR (numerical positive value < 1)
+  (s_quad <- itemselect(o, select.method = "quadratic", FDR = 0.001))
   (s_lin <- itemselect(o, select.method = "linear", FDR = 0.001))
   (s_ANOVA <- itemselect(o, select.method = "ANOVA", FDR = 0.001))
-}
 
-# no options in shiny
-(f <- drcfit(s_quad, progressbar = TRUE))
-if (visualize)
-{
+  (f <- drcfit(s_quad, progressbar = TRUE))
   f$fitres
   plot(f)
   
-}
-
-
-if (visualize) 
-{
   # various plot of fitted curves (without data)
   curvesplot(f$fitres, xmax = max(f$omicdata$dose), 
              facetby = "model", colorby = "model")
@@ -79,10 +71,6 @@ if (visualize)
   curvesplot(f$fitres[f$fitres$trend == "bell", ], xmax = max(f$omicdata$dose), 
              facetby = "id")
   
-}
-
-if (visualize) 
-{
   curvesplot(f$fitres[f$fitres$trend == "U", ], xmax = max(f$omicdata$dose), 
              facetby = "id")
 }
@@ -90,15 +78,14 @@ if (visualize)
 
 # calculation of benchmark doses
 # options in shiny : z (numerical positive value), x (numerical positive value : percentage)
-(r <- bmdcalc(f, z = 1, x = 10))
-if (visualize)
-(r.2 <- bmdcalc(f, z = 2, x = 50))
+if (visualize) 
+{
+  (r <- bmdcalc(f, z = 1, x = 10))
+  (r.2 <- bmdcalc(f, z = 2, x = 50))
 
 # plot of BMD
 # options in shiny : BMDtype (2 possibilities), plottype (3 possibilities), by (3 possibilities)
 # hist.bins (integer for hist only)
-if (visualize) 
-{
   plot(r, BMDtype = "zSD", plottype = "ecdf", by = "none") 
   
   plot(r, BMDtype = "xfold", plottype = "ecdf", by = "none") 
@@ -109,11 +96,15 @@ if (visualize)
   plot(r, plottype = "hist", by = "trend", hist.bins = 10) 
 }
 
-# Calculation of confidence intervals on BMDs by Bootstrap
-niter <- 1000
-niter <- 10
-b <- bmdboot(r, niter = niter) # niter should be fixed at least at 1000 to get a reasonable precision
-if (visualize) plot(b)
+if (doboot)
+{
+  # Calculation of confidence intervals on BMDs by Bootstrap
+  niter <- 1000
+  niter <- 10
+  b <- bmdboot(r, niter = niter) # niter should be fixed at least at 1000 to get a reasonable precision
+  if (visualize) plot(b)
+  
+}
 
 if(visualize) # too long computation !
 {
